<?php

namespace App\Controller;

use App\Http\HttpRequest;
use App\Http\HttpResponse;
use App\Http\ViewHttpResponse;
use App\Model\TeamModel;
use App\Validation\FieldValidationFail;
use App\Validation\Validators;

class TeamController {
    private TeamModel $model;

    /**
     * @param TeamModel $model
     */
    public function __construct(TeamModel $model) {
        $this->model = $model;
    }

    public function displaySubmitTeam(): HttpResponse {
        return ViewHttpResponse::twig("insert_team.html.twig", []);
    }

    /**
     * @param array<string, mixed> $request
     * @return HttpResponse
     */
    public function submitTeam(array $request): HttpResponse {
        $errors = [];

        $request = HttpRequest::from($request, $errors, [
            "name" => [Validators::lenBetween(1, 32), Validators::nameWithSpaces()],
            "mainColor" => [Validators::regex('/#(?:[0-9a-fA-F]{6})/')],
            "secondColor" => [Validators::regex('/#(?:[0-9a-fA-F]{6})/')],
            "picture" => [Validators::isURL()],
        ]);
        if (!empty($errors)) {
            $badFields = [];
            foreach ($errors as $e) {
                if ($e instanceof FieldValidationFail) {
                    $badFields[] = $e->getFieldName();
                }
            }
            return ViewHttpResponse::twig('insert_team.html.twig', ['bad_fields' => $badFields]);
        }
        return $this->getTeam($this->model->createTeam($request['name'], $request['picture'], $request['mainColor'], $request['secondColor']));
    }

    public function displayListTeamByName(): HttpResponse {
        return ViewHttpResponse::twig("list_team_by_name.html.twig", []);
    }

    /**
     * @param array<string , mixed> $request
     * @return HttpResponse
     */
    public function listTeamByName(array $request): HttpResponse {
        $errors = [];
        $request = HttpRequest::from($request, $errors, [
            "name" => [Validators::lenBetween(1, 32), Validators::nameWithSpaces()],
        ]);

        if (!empty($errors) && $errors[0] instanceof FieldValidationFail) {
            $badField = $errors[0]->getFieldName();
            return ViewHttpResponse::twig('list_team_by_name.html.twig', ['bad_field' => $badField]);
        }

        $results = $this->model->listByName($request['name']);

        if (empty($results)) {
            return ViewHttpResponse::twig('display_teams.html.twig', []);
        }

        return ViewHttpResponse::twig('display_teams.html.twig', ['teams' => $results]);
    }

    public function getTeam(int $id): HttpResponse {
        $result = $this->model->displayTeam($id);
        return ViewHttpResponse::twig('display_team.html.twig', ['team' => $result]);
    }
}
