<?php

namespace App\Gateway;

use App\Connexion;
use PDO;

class TeamGateway {
    private Connexion $con;

    public function __construct(Connexion $con) {
        $this->con = $con;
    }

    public function insert(string $name, string $picture, string $mainColor, string $secondColor): void {
        $this->con->exec(
            "INSERT INTO Team(name, picture, mainColor, secondColor) VALUES (:teamName , :picture, :mainColor, :secondColor)",
            [
                ":teamName" => [$name, PDO::PARAM_STR],
                ":picture" => [$picture, PDO::PARAM_STR],
                ":mainColor" => [$mainColor, PDO::PARAM_STR],
                ":secondColor" => [$secondColor, PDO::PARAM_STR],
            ]
        );
    }

    /**
     * @param string $name
     * @return array<string,mixed>[]
     */
    public function listByName(string $name): array {
        return $this->con->fetch(
            "SELECT id,name,picture,mainColor,secondColor FROM Team WHERE name LIKE '%' || :name || '%'",
            [
                ":name" => [$name, PDO::PARAM_STR],
            ]
        );
    }

    /**
     * @param int $id
     * @return array<string,mixed>[]
     */
    public function getTeamById(int $id): array {
        return $this->con->fetch(
            "SELECT id,name,picture,mainColor,secondColor FROM Team WHERE id = :id",
            [
                ":id" => [$id, PDO::PARAM_INT],
            ]
        );
    }

    /**
     * @param string $name
     * @return array<string,int>[]
     */
    public function getIdTeamByName(string $name): array {
        return $this->con->fetch(
            "SELECT id FROM Team WHERE name = :name",
            [
                ":name" => [$name, PDO::PARAM_STR],
            ]
        );
    }

    /**
     * @param int $id
     * @return array<string,mixed>[]
     */
    public function getMembersById(int $id): array {
        return $this->con->fetch(
            "SELECT m.role,u.id FROM User u,Team t,Member m WHERE t.id = :id AND m.idTeam = t.id AND m.idMember = u.id",
            [
              ":id" => [$id, PDO::PARAM_INT],
          ]
        );
    }

}
